==> haskell-interpolate-0.2.1-462.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-interpolate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 interpolate
version:              0.2.1
visibility:           public
id:                   interpolate-0.2.1-11Lx1Ia4aQr9a8RI0Bw85G
key:                  interpolate-0.2.1-11Lx1Ia4aQr9a8RI0Bw85G
license:              MIT
copyright:            (c) 2013-2015 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://github.com/sol/interpolate#readme
synopsis:             String interpolation done right
description:          String interpolation done right
category:             Data, Text
abi:                  352fc8c07dde97bcd39070a761bb22ea
exposed:              True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.IsString
    Data.String.Interpolate.Util

hidden-modules:
    Data.String.Interpolate.Compat
    Data.String.Interpolate.Internal.Util Data.String.Interpolate.Parse
    Paths_interpolate

import-dirs:          /usr/lib/ghc-9.6.6/site-local/interpolate-0.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/interpolate-0.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/interpolate-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-interpolate
hs-libraries:         HSinterpolate-0.2.1-11Lx1Ia4aQr9a8RI0Bw85G
depends:
    base-4.18.2.1 haskell-src-meta-0.8.15-GqSWx9monJhDwN3u4roT6d
    template-haskell-2.20.0.0

haddock-interfaces:   /usr/share/doc/haskell-interpolate/html/interpolate.haddock
haddock-html:         /usr/share/doc/haskell-interpolate/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-interpolate-0.2.1-463-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-interpolate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 interpolate
version:              0.2.1
visibility:           public
id:                   interpolate-0.2.1-F5dcfS7uiJZMsqc5vNfgk
key:                  interpolate-0.2.1-F5dcfS7uiJZMsqc5vNfgk
license:              MIT
copyright:            (c) 2013-2015 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://github.com/sol/interpolate#readme
synopsis:             String interpolation done right
description:          String interpolation done right
category:             Data, Text
abi:                  47f4bf74a404863128109fbc211d8567
exposed:              True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.IsString
    Data.String.Interpolate.Util

hidden-modules:
    Data.String.Interpolate.Compat
    Data.String.Interpolate.Internal.Util Data.String.Interpolate.Parse
    Paths_interpolate

import-dirs:          /usr/lib/ghc-9.6.6/site-local/interpolate-0.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/interpolate-0.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/interpolate-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-interpolate
hs-libraries:         HSinterpolate-0.2.1-F5dcfS7uiJZMsqc5vNfgk
depends:
    base-4.18.2.1 haskell-src-meta-0.8.15-5WA14dofYHdB0COx7SkwL2
    template-haskell-2.20.0.0

haddock-interfaces:   /usr/share/doc/haskell-interpolate/html/interpolate.haddock
haddock-html:         /usr/share/doc/haskell-interpolate/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
